@@ -4,10 +4,10 @@
 @Contact :   g1879@qq.com
 @File    :   common.py
 """
-import re
-import shutil
 from abc import abstractmethod
 from pathlib import Path
+from re import split as re_SPLIT
+from shutil import rmtree
 from typing import Union
 
 from requests_html import Element
@@ -15,6 +15,8 @@ from selenium.webdriver.remote.webelement import WebElement
 
 
 class DrissionElement(object):
+    """SessionElement和DriverElement的基类"""
+
     def __init__(self, ele: Union[Element, WebElement]):
         self._inner_ele = ele
 
@@ -50,12 +52,20 @@ class DrissionElement(object):
     def prev(self):
         return
 
+    @property
+    def css_path(self):
+        return
+
+    @property
+    def xpath(self):
+        return
+
     @abstractmethod
-    def ele(self, loc: tuple, mode: str = None, show_errmsg: bool = True):
+    def ele(self, loc: Union[tuple, str], mode: str = None, show_errmsg: bool = True):
         pass
 
     @abstractmethod
-    def eles(self, loc: tuple, show_errmsg: bool = True):
+    def eles(self, loc: Union[tuple, str], show_errmsg: bool = True):
         pass
 
     @abstractmethod
@@ -64,26 +74,26 @@ class DrissionElement(object):
 
 
 def get_loc_from_str(loc: str) -> tuple:
-    """处理元素查找语句
-    查找方式：属性、tag name及属性、文本、xpath、css selector
-    =表示精确匹配，:表示模糊匹配，无控制字符串时默认搜索该字符串
-    例：
-    @class:ele_class - class含有ele_class的元素
-    @class=ele_class - class等于ele_class的元素
-    @class - 带class属性的元素
-    tag:div - div元素
-    tag:div@class:ele_class - class含有ele_class的div元素
-    tag:div@class=ele_class - class等于ele_class的div元素
-    tag:div@text():search_text - 文本含有search_text的div元素
-    tag:div@text()=search_text - 文本等于search_text的div元素
-    text:search_text - 文本含有search_text的元素
-    text=search_text - 文本等于search_text的元素
-    xpath://div[@class="ele_class"]
-    css:div.ele_class
+    """处理元素查找语句                                               \n
+    查找方式：属性、tag name及属性、文本、xpath、css selector           \n
+    =表示精确匹配，:表示模糊匹配，无控制字符串时默认搜索该字符串           \n
+    示例：                                                            \n
+        @class:ele_class - class含有ele_class的元素                    \n
+        @class=ele_class - class等于ele_class的元素                    \n
+        @class - 带class属性的元素                                     \n
+        tag:div - div元素                                              \n
+        tag:div@class:ele_class - class含有ele_class的div元素          \n
+        tag:div@class=ele_class - class等于ele_class的div元素           \n
+        tag:div@text():search_text - 文本含有search_text的div元素        \n
+        tag:div@text()=search_text - 文本等于search_text的div元素        \n
+        text:search_text - 文本含有search_text的元素                     \n
+        text=search_text - 文本等于search_text的元素                     \n
+        xpath://div[@class="ele_class"]                                 \n
+        css:div.ele_class                                               \n
     """
     loc_by = 'xpath'
     if loc.startswith('@'):  # 根据属性查找
-        r = re.split(r'([:=])', loc[1:], maxsplit=1)
+        r = re_SPLIT(r'([:=])', loc[1:], maxsplit=1)
         if len(r) == 3:
             mode = 'exact' if r[1] == '=' else 'fuzzy'
             loc_str = _make_xpath_str('*', f'@{r[0]}', r[2], mode)
@@ -94,7 +104,7 @@ def get_loc_from_str(loc: str) -> tuple:
             loc_str = f'//*[name()="{loc[4:]}"]'
         else:
             at_lst = loc[4:].split('@', maxsplit=1)
-            r = re.split(r'([:=])', at_lst[1], maxsplit=1)
+            r = re_SPLIT(r'([:=])', at_lst[1], maxsplit=1)
             if len(r) == 3:
                 mode = 'exact' if r[1] == '=' else 'fuzzy'
                 arg_str = r[0] if r[0] == 'text()' else f'@{r[0]}'
@@ -120,17 +130,28 @@ def get_loc_from_str(loc: str) -> tuple:
     return loc_by, loc_str
 
 
-def _make_xpath_str(tag: str, arg: str, val: str, mode: str = 'fuzzy'):
-    """生成xpath语句"""
+def _make_xpath_str(tag: str, arg: str, val: str, mode: str = 'fuzzy') -> str:
+    """生成xpath语句                                          \n
+    :param tag: 标签名
+    :param arg: 属性名
+    :param val: 属性值
+    :param mode: 'exact' 或 'fuzzy'，对应精确或模糊查找
+    :return: xpath字符串
+    """
     tag_name = '' if tag == '*' else f'name()="{tag}" and '
     if mode == 'exact':
         return f'//*[{tag_name}{arg}={_make_search_str(val)}]'
-    else:
+    elif mode == 'fuzzy':
         return f"//*[{tag_name}contains({arg},{_make_search_str(val)})]"
+    else:
+        raise ValueError("Argument mode can only be 'exact' or 'fuzzy'.")
 
 
-def _make_search_str(search_str: str):
-    """将"转义，不知何故不能直接用\""""
+def _make_search_str(search_str: str) -> str:
+    """将"转义，不知何故不能直接用\  \n
+    :param search_str: 查询字符串
+    :return: 把"转义后的字符串
+    """
     parts = search_str.split('"')
     parts_num = len(parts)
     search_str = 'concat('
@@ -141,8 +162,11 @@ def _make_search_str(search_str: str):
     return search_str
 
 
-def translate_loc_to_xpath(loc):
-    """把By类型转为xpath或css selector"""
+def translate_loc_to_xpath(loc: tuple) -> tuple:
+    """把By类型的loc元组转换为css selector或xpath类型的  \n
+    :param loc: By类型的loc元组
+    :return: css selector或xpath类型的loc元组
+    """
     loc_by = 'xpath'
     loc_str = None
     if loc[0] == 'xpath':
@@ -165,13 +189,14 @@ def translate_loc_to_xpath(loc):
     return loc_by, loc_str
 
 
-def avoid_duplicate_name(folder_path: str, file_name: str) -> str:
-    """检查文件是否重名，并返回可以使用的文件名
+def get_available_file_name(folder_path: str, file_name: str) -> str:
+    """检查文件是否重名，并返回可以使用的文件名  \n
     :param folder_path: 文件夹路径
     :param file_name: 要检查的文件名
     :return: 可用的文件名
     """
-    file_Path = Path(folder_path).joinpath(file_name)
+    folder_path = Path(folder_path).absolute()
+    file_Path = folder_path.joinpath(file_name)
     while file_Path.exists():
         ext_name = file_Path.suffix
         base_name = file_Path.stem
@@ -181,12 +206,12 @@ def avoid_duplicate_name(folder_path: str, file_name: str) -> str:
             file_name = f'{base_name.replace(f"({num})", "", -1)}({num + 1}){ext_name}'
         else:
             file_name = f'{base_name} (1){ext_name}'
-        file_Path = Path(folder_path).joinpath(file_name)
+        file_Path = folder_path.joinpath(file_name)
     return file_name
 
 
-def clean_folder(folder_path: str, ignore: list = None):
-    """清空一个文件夹，除了ignore里的文件和文件夹
+def clean_folder(folder_path: str, ignore: list = None) -> None:
+    """清空一个文件夹，除了ignore里的文件和文件夹  \n
     :param folder_path: 要清空的文件夹路径
     :param ignore: 忽略列表
     :return: None
@@ -198,4 +223,4 @@ def clean_folder(folder_path: str, ignore: list = None):
             if f.is_file():
                 f.unlink()
             elif f.is_dir():
-                shutil.rmtree(f, True)
+                rmtree(f, True)
