@@ -213,7 +213,8 @@ class DriverElement(DrissionElement):
 
         if loc_or_str[0] == 'xpath':
             # 确保查询语句最前面是.
-            loc_str = f'.{loc_or_str[1]}' if not loc_or_str[1].startswith('.') else loc_or_str[1]
+            loc_str = loc_or_str[1] if loc_or_str[1].startswith(('.', '/')) else f'.//{loc_or_str[1]}'
+            loc_str = loc_str if loc_str.startswith('.') else f'.{loc_str}'
             loc_or_str = loc_or_str[0], loc_str
         else:
             if loc_or_str[1].lstrip().startswith('>'):
@@ -290,12 +291,13 @@ class DriverElement(DrissionElement):
             print(e)
             return False
 
-    def run_script(self, script: str) -> Any:
-        """执行js                   \n
+    def run_script(self, script: str, *args) -> Any:
+        """执行js代码，传入自己为第一个参数  \n
         :param script: js文本
+        :param args: 传入的参数
         :return: js执行结果
         """
-        return self.inner_ele.parent.execute_script(script, self.inner_ele)
+        return self.inner_ele.parent.execute_script(script, self.inner_ele, *args)
 
     def submit(self) -> None:
         """提交表单"""
