@@ -112,8 +112,11 @@ class DriverPage(object):
         """
         if isinstance(loc_or_ele, str):
             loc_or_ele = get_loc_from_str(loc_or_ele)
+            if loc_or_ele[0] == 'xpath' and not loc_or_ele[1].startswith('/'):
+                loc_or_ele = 'xpath', f'//{loc_or_ele[1]}'
         elif isinstance(loc_or_ele, tuple) and len(loc_or_ele) == 2:
-            pass
+            if loc_or_ele[0] == 'xpath' and not loc_or_ele[1].startswith('/'):
+                loc_or_ele = 'xpath', f'//{loc_or_ele[1]}'
         elif isinstance(loc_or_ele, DriverElement):
             return loc_or_ele
         elif isinstance(loc_or_ele, WebElement):
@@ -216,12 +219,13 @@ class DriverPage(object):
         """
         return None
 
-    def run_script(self, script: str) -> Any:
-        """执行js                 \n
+    def run_script(self, script: str, *args) -> Any:
+        """执行js代码                 \n
         :param script: js文本
+        :param args: 传入的参数
         :return: js执行结果
         """
-        return self.driver.execute_script(script)
+        return self.driver.execute_script(script, *args)
 
     @property
     def tabs_count(self) -> int:
