@@ -99,8 +99,12 @@ class SessionPage(object):
         """
         if isinstance(loc_or_ele, str):
             loc_or_ele = get_loc_from_str(loc_or_ele)
+            if loc_or_ele[0] == 'xpath' and not loc_or_ele[1].startswith('/'):
+                loc_or_ele = 'xpath', f'//{loc_or_ele[1]}'
         elif isinstance(loc_or_ele, tuple) and len(loc_or_ele) == 2:
             loc_or_ele = translate_loc_to_xpath(loc_or_ele)
+            if loc_or_ele[0] == 'xpath' and not loc_or_ele[1].startswith('/'):
+                loc_or_ele = 'xpath', f'//{loc_or_ele[1]}'
         elif isinstance(loc_or_ele, SessionElement):
             return loc_or_ele
         elif isinstance(loc_or_ele, Element):
@@ -155,7 +159,7 @@ class SessionPage(object):
             return
         self._url = to_url
         self._response = self._make_response(to_url, show_errmsg=show_errmsg, **kwargs)[0]
-        if not self._response:
+        if self._response is None:
             self._url_available = False
         else:
             try:
@@ -190,7 +194,7 @@ class SessionPage(object):
             return
         self._url = to_url
         self._response = self._make_response(to_url, mode='post', data=data, show_errmsg=show_errmsg, **kwargs)[0]
-        if not self._response:
+        if self._response is None:
             self._url_available = False
         else:
             try:
@@ -234,10 +238,14 @@ class SessionPage(object):
             kwargs['timeout'] = 20
 
         r, info = self._make_response(file_url, mode='get', show_errmsg=show_errmsg, **kwargs)
-        if not r:
+        if r is None:
             if show_msg:
                 print(info)
             return False, info
+        if not r.ok:
+            if show_errmsg:
+                raise ConnectionError(f'Status code: {r.status_code}.')
+            return False, f'Status code: {r.status_code}.'
         # -------------------获取文件名-------------------
         # header里有文件名，则使用它，否则在url里截取，但不能保证url包含文件名
         if 'Content-disposition' in r.headers:
@@ -298,9 +306,16 @@ class SessionPage(object):
                             rate = downloaded_size / file_size if downloaded_size < file_size else 1
                             print('\r {:.0%} '.format(rate), end="")
         except Exception as e:
+            if show_errmsg:
+                raise ConnectionError(e)
             download_status, info = False, f'Download failed.\n{e}'
         else:
-            download_status, info = (False, 'File size is 0.') if full_path.stat().st_size == 0 else (True, 'Success.')
+            if full_path.stat().st_size == 0:
+                if show_errmsg:
+                    raise ValueError('File size is 0.')
+                download_status, info = False, 'File size is 0.'
+            else:
+                download_status, info = True, 'Success.'
         finally:
             # 删除下载出错文件
             if not download_status and full_path.exists():
@@ -324,7 +339,7 @@ class SessionPage(object):
         :param data: post方式要提交的数据
         :param show_errmsg: 是否显示和抛出异常
         :param kwargs: 其它参数
-        :return: Response对象
+        :return: tuple，第一位为Response或None，第二位为出错信息或'Sussess'
         """
         if mode not in ['get', 'post']:
             raise ValueError("Argument mode can only be 'get' or 'post'.")
@@ -364,7 +379,7 @@ class SessionPage(object):
                 try:
                     charset = re_result.group(1)
                 except:
-                    charset = 'utf-8'
+                    charset = r.apparent_encoding
             else:
                 charset = headers['Content-Type'].split('=')[1]
             # 避免存在退格符导致乱码或解析出错
